@@ -1,12 +1,10 @@
 /*
- * Copyright (c) 2000-2001 Proofpoint, Inc. and its suppliers.
+ * Copyright (c) 2000-2001, 2018 Proofpoint, Inc. and its suppliers.
  *	All rights reserved.
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the LICENSE file which can be found at the top level of
  * the sendmail distribution.
- *
- *	$Id: sm_os_freebsd.h,v 1.12 2013/11/22 20:51:34 ca Exp $
  */
 
 /*
@@ -28,14 +26,19 @@
 #       define SM_CONF_STRL		1
 #    endif
 #  endif
+#  if __FreeBSD_version >= 1200059
+#   ifndef SM_CONF_SEM
+#    define SM_CONF_SEM	2 /* union semun is no longer declared by default */
+#   endif
+#  endif
 #endif
 
 #ifndef SM_CONF_SHM
 # define SM_CONF_SHM	1
-#endif /* SM_CONF_SHM */
+#endif
 #ifndef SM_CONF_SEM
 # define SM_CONF_SEM	1
-#endif /* SM_CONF_SEM */
+#endif
 #ifndef SM_CONF_MSG
 # define SM_CONF_MSG	1
-#endif /* SM_CONF_MSG */
+#endif
