@@ -28,16 +28,16 @@
 
 extern void *sm_shmstart __P((key_t, int , int , int *, bool));
 extern int sm_shmstop __P((void *, int, bool));
-extern int sm_shmsetowner __P((int, uid_t, gid_t, mode_t));
+extern int sm_shmsetowner __P((int, uid_t, gid_t, MODE_T));
 
 
 /* for those braindead systems... (e.g., SunOS 4) */
 #  ifndef SHM_R
 #   define SHM_R       0400
-#  endif /* SHM_R */
+#  endif
 #  ifndef SHM_W
 #   define SHM_W       0200
-#  endif /* SHM_W */
+#  endif
 
 # endif /* SM_CONF_SHM */
 #endif /* ! SM_SHM_H */
