@@ -13,7 +13,7 @@
 #define DAEMON_H 1
 
 #if DAEMON_C
-# define EXTERN 
+# define EXTERN
 #else
 # define EXTERN extern
 #endif
@@ -43,10 +43,10 @@ struct daemon
 #if MILTER
 	char		*d_inputfilterlist;
 	struct milter	*d_inputfilters[MAXFILTERS];
-#endif /* MILTER */
+#endif
 #if _FFR_SS_PER_DAEMON
 	int		d_supersafe;
-#endif /* _FFR_SS_PER_DAEMON */
+#endif
 };
 
 typedef struct daemon DAEMON_T;
