@@ -817,7 +817,7 @@ hn2alabel(hostname)
 	UIDNA *idna;
 	static char buf[MAXNAME_I];	/* XXX ??? */
 
-	if (addr_is_ascii(hostname))
+	if (str_is_print(hostname))
 		return hostname;
 	idna = uidna_openUTS46(UIDNA_NONTRANSITIONAL_TO_ASCII, &error);
 	(void) uidna_nameToASCII_UTF8(idna, hostname, strlen(hostname),
@@ -942,7 +942,7 @@ getmxrr(host, mxhosts, mxprefs, flags, rcode, pttl, port, pad)
 # endif /* DANE */
 
 # if USE_EAI
-	if (!addr_is_ascii(host))
+	if (!str_is_print(host))
 	{
 		/* XXX memory leak? */
 		host = sm_rpool_strdup_x(CurEnv->e_rpool, hn2alabel(host));
@@ -1321,7 +1321,7 @@ punt:
 					char *hn;
 
 					hn = MXHostBuf + 1;
-					if (!addr_is_ascii(hn))
+					if (!str_is_print(hn))
 					{
 						const char *ahn;
 
